import { isPlatformBrowser, DOCUMENT } from '@angular/common';
import { ɵɵdefineInjectable, ɵɵinject, PLATFORM_ID, Injectable, Inject, NgModule } from '@angular/core';
import { BehaviorSubject, Subject } from 'rxjs';

// @dynamic
class WindowService {
    constructor(document, 
    // tslint:disable-next-line: ban-types
    platformId) {
        this.document = document;
        this.platformId = platformId;
        this.width$ = new BehaviorSubject(1200);
        this.scrollingUp$ = new BehaviorSubject(true);
        this.currentScrollPosition = 0;
        if (this.isBrowser() && this.hasDocument()) {
            this.window = this.document.defaultView;
            this.document.addEventListener('scroll', this.handleContentScroll.bind(this));
            this.width$.next(this.window.innerWidth);
            this.window.addEventListener('resize', () => {
                if (this.window.innerWidth && this.width$.getValue()) {
                    this.width$.next(this.window.innerWidth);
                }
            });
        }
    }
    scrollTo(offset = 0) {
        if (!this.window) {
            return;
        }
        this.window.scrollTo(0, offset);
    }
    hasDocument() {
        return !!this.document;
    }
    isBrowser() {
        return isPlatformBrowser(this.platformId);
    }
    handleContentScroll() {
        if (window.pageYOffset > this.currentScrollPosition) {
            this.scrollingUp$.next(false);
        }
        else {
            this.scrollingUp$.next(true);
        }
        this.currentScrollPosition = window.pageYOffset;
    }
}
WindowService.ɵprov = ɵɵdefineInjectable({ factory: function WindowService_Factory() { return new WindowService(ɵɵinject(DOCUMENT), ɵɵinject(PLATFORM_ID)); }, token: WindowService, providedIn: "root" });
WindowService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
WindowService.ctorParameters = () => [
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: String, decorators: [{ type: Inject, args: [PLATFORM_ID,] }] }
];

class SubscriptionService {
    constructor() {
        this.destroyed$ = new Subject();
    }
    ngOnDestroy() {
        this.destroyed$.next(true);
        this.destroyed$.complete();
    }
}
SubscriptionService.decorators = [
    { type: Injectable }
];

class UtilsModule {
}
UtilsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [],
                imports: [],
                providers: [WindowService],
                exports: [],
            },] }
];

/*
 * Public API Surface of utils
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SubscriptionService, UtilsModule, WindowService };
//# sourceMappingURL=studiohyperdrive-ngx-utils.js.map
